import { Router } from "express";
import {
  upsertSalaryStructures,
  updateSalaryStructure,
  createPayroll,
  updatePayroll,
  getPayrolls,
  getEmployeesWithoutPayroll,
  getPayrollByMonth,
  GetAnEmployeeSalaryStructure,
  getCompanyEmployeesSalaryStructures,
} from "../controllers/payroll/payroll.controller";
import { authenticate } from "../middleware/auth.middleware";
const router = Router();

router.post("/salary-structure", authenticate, upsertSalaryStructures); // [x] Create a new salary structure
router.put("/salary-structure/:id", authenticate, updateSalaryStructure); // [x] Update an existing salary structure
router.get(
  "/salary-structure/employee/:employee_id",
  authenticate,
  GetAnEmployeeSalaryStructure
);
router.get(
  "/salary-structure/:company_id",
  authenticate,
  getCompanyEmployeesSalaryStructures
); // [x] Get salary structure of all employees of a company

router.post("/salary/create", createPayroll); // Create payroll
router.put("/salary/:id", updatePayroll); // Update payroll by ID
router.get("/salary", getPayrolls); // Get all payrolls
router.get("/salary/:year/:month", getPayrollByMonth); // Get payrolls for a specific month with optional employee_id
router.get(
  "/employees-without-payroll/:year/:month",
  getEmployeesWithoutPayroll
);

export default router;
